@@ -3,7 +3,7 @@
    | PHP Version 5 / Imagick	                                          |
    +----------------------------------------------------------------------+
    | Copyright (c) 2006-2013 Mikko Koppanen, Scott MacVicar               |
-   | Imagemagick (c) ImageMagick Studio LLC                               |
+   | ImageMagick (c) ImageMagick Studio LLC                               |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -27,16 +27,17 @@
 /* {{{ proto array ImagickPixel::getHSL()
 	Returns the normalized HSL color of the pixel wand in an array with the keys "hue", "saturation", and "luminosity".
 */
-PHP_METHOD(imagickpixel, gethsl)
+PHP_METHOD(ImagickPixel, getHSL)
 {
 	php_imagickpixel_object *internp;
 	double hue, saturation, luminosity;
 
 	if (zend_parse_parameters_none() == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
-	
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
 
 	PixelGetHSL(internp->pixel_wand, &hue, &saturation, &luminosity);
 
@@ -44,24 +45,24 @@ PHP_METHOD(imagickpixel, gethsl)
 	add_assoc_double(return_value, "hue", hue);
 	add_assoc_double(return_value, "saturation", saturation);
 	add_assoc_double(return_value, "luminosity", luminosity);
-	return;
 }
 /* }}} */
 
 /* {{{ proto bool ImagickPixel::setHSL(float hue, float saturation, float luminosity)
 	Sets the normalized HSL color of the pixel wand.
 */
-PHP_METHOD(imagickpixel, sethsl)
+PHP_METHOD(ImagickPixel, setHSL)
 {
 	php_imagickpixel_object *internp;
 	double hue, saturation, luminosity;
 
 	/* Parse parameters given to function */
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ddd", &hue, &saturation, &luminosity) == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
 
 	PixelSetHSL(internp->pixel_wand, hue, saturation, luminosity);
 	RETURN_TRUE;
@@ -72,19 +73,20 @@ PHP_METHOD(imagickpixel, sethsl)
 	Gets the quantum value of a color in the ImagickPixel. Quantum is a float if ImageMagick was compiled with HDRI
 	otherwise an integer.
 */
-PHP_METHOD(imagickpixel, getcolorvaluequantum)
+PHP_METHOD(ImagickPixel, getColorValueQuantum)
 {
 	php_imagickpixel_object *internp;
-	long color;
+	im_long color;
 	Quantum color_value;
 
 	/* Parse parameters given to function */
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &color) == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 	
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
-	
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
+
 	switch (color) {
 
 		case PHP_IMAGICK_COLOR_BLACK:
@@ -115,9 +117,11 @@ PHP_METHOD(imagickpixel, getcolorvaluequantum)
 			color_value = PixelGetMagentaQuantum(internp->pixel_wand);
 		break;
 
+#if MagickLibVersion < 0x700
 		case PHP_IMAGICK_COLOR_OPACITY:
 			color_value = PixelGetOpacityQuantum(internp->pixel_wand);
 		break;
+#endif
 
 		case PHP_IMAGICK_COLOR_ALPHA:
 			color_value = PixelGetAlphaQuantum(internp->pixel_wand);
@@ -125,11 +129,11 @@ PHP_METHOD(imagickpixel, getcolorvaluequantum)
 
 		default:
 			php_imagick_throw_exception (IMAGICKPIXEL_CLASS, "Unknown color type" TSRMLS_CC);
-			return;
+			RETURN_THROWS();
 		break;
 	}
 	
-#ifdef MAGICKCORE_HDRI_ENABLE
+#if MAGICKCORE_HDRI_ENABLE
 	RETVAL_DOUBLE(color_value);
 #else
 	RETVAL_LONG(color_value);
@@ -140,27 +144,27 @@ PHP_METHOD(imagickpixel, getcolorvaluequantum)
 /* {{{ proto bool ImagickPixel::setColorValueQuantum(int color, float value)
 	Sets the quantum color of the ImagickPixel.
 */
-PHP_METHOD(imagickpixel, setcolorvaluequantum)
+PHP_METHOD(ImagickPixel, setColorValueQuantum)
 {
 	php_imagickpixel_object *internp;
-	long color;
+	im_long color;
 
-
-#ifdef MAGICKCORE_HDRI_ENABLE
+#if MAGICKCORE_HDRI_ENABLE
 	double color_value;
 	/* Parse parameters given to function */
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ld", &color, &color_value) == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 #else
-	long color_value;
+	im_long color_value;
 	/* Parse parameters given to function */
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ll", &color, &color_value) == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 #endif
 	
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
 
 	switch (color) {
 
@@ -192,9 +196,11 @@ PHP_METHOD(imagickpixel, setcolorvaluequantum)
 			PixelSetMagentaQuantum(internp->pixel_wand, color_value);
 		break;
 
+#if MagickLibVersion < 0x700
 		case PHP_IMAGICK_COLOR_OPACITY:
 			PixelSetOpacityQuantum(internp->pixel_wand, color_value);
 		break;
+#endif
 
 		case PHP_IMAGICK_COLOR_ALPHA:
 			PixelSetAlphaQuantum(internp->pixel_wand, color_value);
@@ -202,7 +208,7 @@ PHP_METHOD(imagickpixel, setcolorvaluequantum)
 
 		default:
 			php_imagick_throw_exception (IMAGICKPIXEL_CLASS, "Unknown color type" TSRMLS_CC);
-			return;
+			RETURN_THROWS();
 		break;
 	}
 	RETVAL_TRUE;
@@ -212,15 +218,17 @@ PHP_METHOD(imagickpixel, setcolorvaluequantum)
 /* {{{ proto bool ImagickPixel::getIndex()
 	Gets the colormap index of the pixel wand 
 */
-PHP_METHOD(imagickpixel, getindex)
+PHP_METHOD(ImagickPixel, getIndex)
 {
 	php_imagickpixel_object *internp;
 
 	if (zend_parse_parameters_none() == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
-	
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
+
 	RETVAL_LONG(PixelGetIndex(internp->pixel_wand));
 }
 /* }}} */
@@ -228,17 +236,26 @@ PHP_METHOD(imagickpixel, getindex)
 /* {{{ proto bool ImagickPixel::setIndex(int pixel_packet)
 	Sets the colormap index of the pixel wand 
 */
-PHP_METHOD(imagickpixel, setindex)
+PHP_METHOD(ImagickPixel, setIndex)
 {
 	php_imagickpixel_object *internp;
-	long index;
+#if MAGICKCORE_HDRI_ENABLE
+	double index;
+
+	/* Parse parameters given to function */
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "d", &index) == FAILURE) {
+#else
+	im_long index;
 
 	/* Parse parameters given to function */
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &index) == FAILURE) {
-		return;
+#endif
+		RETURN_THROWS();
 	}
-	
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
+
 	PixelSetIndex(internp->pixel_wand, index);
 	RETURN_TRUE;
 }
@@ -248,29 +265,37 @@ PHP_METHOD(imagickpixel, setindex)
 /* {{{ proto ImagickPixel ImagickPixel::__construct([string color] )
    The ImagickPixel constructor
 */
-PHP_METHOD(imagickpixel, __construct)
+PHP_METHOD(ImagickPixel, __construct)
 {
 	php_imagickpixel_object *internp;
 	char *color_name = NULL;
-	int color_name_len = 0;
+	IM_LEN_TYPE color_name_len = 0;
+
+	// This suppresses an 'unused parameter' warning.
+	(void)return_value;
 
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|s", &color_name, &color_name_len) == FAILURE) {
-		return;
+		RETURN_THROWS();
+	}
+
+	internp = Z_IMAGICKPIXEL_P(getThis());
+
+	if (internp->pixel_wand != NULL) {
+		DestroyPixelWand(internp->pixel_wand);
 	}
 
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
 	internp->pixel_wand = NewPixelWand();
 
 	if (!internp->pixel_wand) {
 		php_imagick_throw_exception (IMAGICKPIXEL_CLASS, "Failed to allocate PixelWand structure" TSRMLS_CC);
-		return;
+		RETURN_THROWS();
 	}
 
 	/* If color was given as parameter, set it here.*/
 	if (color_name && color_name_len) {
 		if (PixelSetColor(internp->pixel_wand, color_name) == MagickFalse) {
 			php_imagick_throw_exception (IMAGICKPIXEL_CLASS, "Unable to construct ImagickPixel" TSRMLS_CC);
-			return;
+			RETURN_THROWS();
 		}
 	}
 }
@@ -279,25 +304,27 @@ PHP_METHOD(imagickpixel, __construct)
 /* {{{ proto bool ImagickPixel::setColor(string color)
 	Sets the color of the pixel wand with a string (e.g. "blue", "#0000ff", "rgb(0,0,255)", "cmyk(100,100,100,10)", etc.).
 */
-PHP_METHOD(imagickpixel, setcolor)
+PHP_METHOD(ImagickPixel, setColor)
 {
 	char *color_name;
-	int color_name_len;
+	IM_LEN_TYPE color_name_len;
 	
 	php_imagickpixel_object *internp;
 	MagickBooleanType status;
 
 	/* Parse parameters given to function */
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &color_name, &color_name_len) == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 	
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
+
 	status = PixelSetColor(internp->pixel_wand, color_name);
 
 	if (status == MagickFalse) {
 		php_imagick_convert_imagickpixel_exception (internp->pixel_wand, "Unable to set ImagickPixel color" TSRMLS_CC);
-		return;
+		RETURN_THROWS();
 	}
 
 	RETURN_TRUE;
@@ -307,15 +334,16 @@ PHP_METHOD(imagickpixel, setcolor)
 /* {{{ proto bool ImagickPixel::clear()
 	Clears resources associated with the wand.
 */
-PHP_METHOD(imagickpixel, clear)
+PHP_METHOD(ImagickPixel, clear)
 {
 	php_imagickpixel_object *internp;
 
 	if (zend_parse_parameters_none() == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
 
 	ClearPixelWand(internp->pixel_wand);
 	RETURN_TRUE;
@@ -337,10 +365,11 @@ void s_is_pixelwand_similar(INTERNAL_FUNCTION_PARAMETERS, zend_bool use_quantum)
 
 	/* Parse parameters given to function */
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "zd", &param, &fuzz) == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
 
 	color_wand = php_imagick_zval_to_pixelwand (param, IMAGICKPIXEL_CLASS, &allocated TSRMLS_CC);
 	if (!color_wand)
@@ -364,7 +393,7 @@ void s_is_pixelwand_similar(INTERNAL_FUNCTION_PARAMETERS, zend_bool use_quantum)
 	The maximum value represents the longest possible distance in the colorspace.
 	e.g. from RGB(0, 0, 0) to RGB(255, 255, 255) for the RGB colorspace
 */
-PHP_METHOD(imagickpixel, ispixelsimilarquantum)
+PHP_METHOD(ImagickPixel, isPixelSimilarQuantum)
 {
 	s_is_pixelwand_similar (INTERNAL_FUNCTION_PARAM_PASSTHRU, 0);
 }
@@ -376,7 +405,7 @@ PHP_METHOD(imagickpixel, ispixelsimilarquantum)
 	The maximum value represents the longest possible distance in the colorspace.
 	e.g. from RGB(0, 0, 0) to RGB(255, 255, 255) for the RGB colorspace
 */
-PHP_METHOD(imagickpixel, ispixelsimilar)
+PHP_METHOD(ImagickPixel, isPixelSimilar)
 {
 	s_is_pixelwand_similar (INTERNAL_FUNCTION_PARAM_PASSTHRU, 1);
 }
@@ -385,23 +414,24 @@ PHP_METHOD(imagickpixel, ispixelsimilar)
 /* {{{ proto float ImagickPixel::getColorValue(int color)
 	Gets the normalized value of a color in the ImagickPixel.
 */
-PHP_METHOD(imagickpixel, getcolorvalue)
+PHP_METHOD(ImagickPixel, getColorValue)
 {
 	php_imagick_color_t color_enum;
 	php_imagickpixel_object *internp;
-	long color;
+	im_long color;
 	double color_value = 0;
 
 	/* Parse parameters given to function */
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &color) == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
 
 	if (color <= PHP_IMAGICK_COLOR_MIN || color >= PHP_IMAGICK_COLOR_MAX) {
 		php_imagick_throw_exception (IMAGICKPIXEL_CLASS, "Unknown color type" TSRMLS_CC);
-		return;
+		RETURN_THROWS();
 	}
 
 	color_enum = color;
@@ -436,9 +466,11 @@ PHP_METHOD(imagickpixel, getcolorvalue)
 			color_value = PixelGetMagenta(internp->pixel_wand);
 		break;
 
+#if MagickLibVersion < 0x700
 		case PHP_IMAGICK_COLOR_OPACITY:
 			color_value = PixelGetOpacity(internp->pixel_wand);
 		break;
+#endif
 
 		case PHP_IMAGICK_COLOR_ALPHA:
 			color_value = PixelGetAlpha(internp->pixel_wand);
@@ -452,7 +484,7 @@ PHP_METHOD(imagickpixel, getcolorvalue)
 
 		default:
 			php_imagick_throw_exception (IMAGICKPIXEL_CLASS, "Unknown color type" TSRMLS_CC);
-			return;
+			RETURN_THROWS();
 		break;
 	}
 	RETVAL_DOUBLE(color_value);
@@ -462,23 +494,24 @@ PHP_METHOD(imagickpixel, getcolorvalue)
 /* {{{ proto float ImagickPixel::setColorValue(int color, float value )
 	Sets the normalized color of the ImagickPixel.
 */
-PHP_METHOD(imagickpixel, setcolorvalue)
+PHP_METHOD(ImagickPixel, setColorValue)
 {
 	php_imagick_color_t color_enum;
 	php_imagickpixel_object *internp;
-	long color;
+	im_long color;
 	double color_value;
 
 	/* Parse parameters given to function */
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ld", &color, &color_value) == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
 
 	if (color <= PHP_IMAGICK_COLOR_MIN || color >= PHP_IMAGICK_COLOR_MAX) {
 		php_imagick_throw_exception (IMAGICKPIXEL_CLASS, "Unknown color type" TSRMLS_CC);
-		return;
+		RETURN_THROWS();
 	}
 
 	color_enum = color;
@@ -513,9 +546,11 @@ PHP_METHOD(imagickpixel, setcolorvalue)
 			PixelSetMagenta(internp->pixel_wand, color_value);
 		break;
 
+#if MagickLibVersion < 0x700
 		case PHP_IMAGICK_COLOR_OPACITY:
 			PixelSetOpacity(internp->pixel_wand, color_value);
 		break;
+#endif
 
 		case PHP_IMAGICK_COLOR_ALPHA:
 			PixelSetAlpha(internp->pixel_wand, color_value);
@@ -529,7 +564,7 @@ PHP_METHOD(imagickpixel, setcolorvalue)
 
 		default:
 			php_imagick_throw_exception (IMAGICKPIXEL_CLASS, "Unknown color type" TSRMLS_CC);
-			return;
+			RETURN_THROWS();
 		break;
 	}
 	RETVAL_TRUE;
@@ -544,18 +579,19 @@ PHP_METHOD(imagickpixel, setcolorvalue)
 	normalization - 2 - values returned in the range 0,255 and will be ints including alpha
 	values i.e. float if ImageMagick was compiled with HDRI, or integers normally.
 */
-PHP_METHOD(imagickpixel, getcolor)
+PHP_METHOD(ImagickPixel, getColor)
 {
 	php_imagickpixel_object *internp;
-	long normalization = 0;
+	im_long normalization = 0;
 	double red, green, blue, alpha;
 
 	/* Parse parameters given to function */
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|l", &normalization) == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
 	array_init(return_value);
 
 	red   = PixelGetRed(internp->pixel_wand);
@@ -603,8 +639,6 @@ PHP_METHOD(imagickpixel, getcolor)
 			break;
 		}
 	}
-
-	return;
 }
 /* }}} */
 
@@ -613,16 +647,17 @@ PHP_METHOD(imagickpixel, getcolor)
 	Returns the color of the pixel in an array as Quantum values. If ImageMagick was compiled
 	as HDRI these will be floats, otherwise they will be integers
 */
-PHP_METHOD(imagickpixel, getcolorquantum)
+PHP_METHOD(ImagickPixel, getColorQuantum)
 {
 	php_imagickpixel_object *internp;
 	Quantum red, green, blue, alpha;
 
 	if (zend_parse_parameters_none() == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
 	array_init(return_value);
 
 	red   = PixelGetRedQuantum(internp->pixel_wand);
@@ -631,7 +666,7 @@ PHP_METHOD(imagickpixel, getcolorquantum)
 	alpha = PixelGetAlphaQuantum(internp->pixel_wand);
 
 
-#ifdef MAGICKCORE_HDRI_ENABLE
+#if MAGICKCORE_HDRI_ENABLE
 	add_assoc_double(return_value, "r", red);
 	add_assoc_double(return_value, "g", green);
 	add_assoc_double(return_value, "b", blue);
@@ -642,76 +677,74 @@ PHP_METHOD(imagickpixel, getcolorquantum)
 	add_assoc_long(return_value, "b", (long)blue);
 	add_assoc_long(return_value, "a", (long)alpha);
 #endif
-
-	return;
 }
 /* }}} */
 
 /* {{{ proto array ImagickPixel::getColorAsString(void )
         Returns the color as a string
 */
-PHP_METHOD(imagickpixel, getcolorasstring)
+PHP_METHOD(ImagickPixel, getColorAsString)
 {
 	php_imagickpixel_object *internp;
 	char *color_string;
 
 	if (zend_parse_parameters_none() == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
 
 	color_string = PixelGetColorAsString(internp->pixel_wand);
-	ZVAL_STRING(return_value, color_string, 1);
+	IM_ZVAL_STRING(return_value, color_string);
 
 	IMAGICK_FREE_MAGICK_MEMORY(color_string);
-	return;
 }
 /* }}} */
 
 /* {{{ proto ImagickPixel ImagickPixel::clone(void)
         Clones the ImagickPixel
 */
-PHP_METHOD(imagickpixel, clone)
+PHP_METHOD(ImagickPixel, clone)
 {
 	php_imagickpixel_object *internp;
 	php_imagickpixel_object *intern_return;
 	PixelWand *pixel_wand;
 
 	if (zend_parse_parameters_none() == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 
 	IMAGICK_METHOD_DEPRECATED("ImagickPixel", "clone");
 
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
 
 	pixel_wand = php_imagick_clone_pixelwand (internp->pixel_wand);
 	if (!pixel_wand) {
 		php_imagick_throw_exception (IMAGICKPIXEL_CLASS, "Failed to allocate" TSRMLS_CC);
-		return;
+		RETURN_THROWS();
 	}
 
 	object_init_ex(return_value, php_imagickpixel_sc_entry);
-	intern_return = (php_imagickpixel_object *)zend_object_store_get_object(return_value TSRMLS_CC);
+	intern_return = Z_IMAGICKPIXEL_P(return_value);
 
 	php_imagick_replace_pixelwand(intern_return, pixel_wand);
-	return;
 }
 /* }}} */
 
 /* {{{ proto int ImagickPixel::getColorCount()
 	Returns the color count associated with this color.
 */
-PHP_METHOD(imagickpixel, getcolorcount)
+PHP_METHOD(ImagickPixel, getColorCount)
 {
 	php_imagickpixel_object *internp;
 
 	if (zend_parse_parameters_none() == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 	
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
 
 	RETVAL_LONG(PixelGetColorCount(internp->pixel_wand));
 }
@@ -720,19 +753,46 @@ PHP_METHOD(imagickpixel, getcolorcount)
 /* {{{ proto int ImagickPixel::setColorCount(int colorCount)
 	Sets the color count associated with this color.
 */
-PHP_METHOD(imagickpixel, setcolorcount)
+PHP_METHOD(ImagickPixel, setColorCount)
 {
 	php_imagickpixel_object *internp;
-	long color_count;
+	im_long color_count;
 
 	/* Parse parameters given to function */
 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &color_count) == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 
-	internp = (php_imagickpixel_object *)zend_object_store_get_object(getThis() TSRMLS_CC);
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
 
     PixelSetColorCount(internp->pixel_wand, color_count);
 	RETVAL_TRUE;
 }
 /* }}} */
+
+#if MagickLibVersion >= 0x693
+/* {{{ proto bool ImagickPixel::setColorFromPixel(ImagickPixel $srcPixel)
+	Sets the color count associated with this color from another ImagickPixel object.
+*/
+PHP_METHOD(ImagickPixel, setColorFromPixel)
+{
+	php_imagickpixel_object *internp, *src_pixel;
+	zval *objvar;
+
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "O", &objvar, php_imagickpixel_sc_entry) == FAILURE) {
+		RETURN_THROWS();
+	}
+
+	internp = Z_IMAGICKPIXEL_P(getThis());
+	IMAGICK_PIXEL_NOT_EMPTY(internp);
+	src_pixel = Z_IMAGICKPIXEL_P(objvar);
+	IMAGICK_PIXEL_NOT_EMPTY(src_pixel);
+
+	PixelSetColorFromWand(internp->pixel_wand, src_pixel->pixel_wand);
+
+	RETVAL_TRUE;
+}
+/* }}} */
+
+#endif //#if MagickLibVersion >= 0x693
